pub enum Call<T: Config> {
initialize_pallet {
new_count: u32,
witness_count: Option<u32>,
},
set_compute {
compute: FixedU64,
},
set_storage {
storage: FixedU64,
},
bloat {
garbage: Vec<[u8; 1024]>,
},
set_block_length {
block_length: FixedU64,
},
// some variants omitted
}Expand description
Contains a variant per dispatchable extrinsic that this pallet has.
Variants
initialize_pallet
Initialize the pallet. Should be called once, if no genesis state was provided.
current_count is the current number of elements in TrashData. This can be set to
None when the pallet is first initialized.
Only callable by Root or AdminOrigin. A good default for new_count is 5_000.
set_compute
Set how much of the remaining ref_time weight should be consumed by on_idle.
Only callable by Root or AdminOrigin.
set_storage
Set how much of the remaining proof_size weight should be consumed by on_idle.
1.0 means that all remaining proof_size will be consumed. The PoV benchmarking
results that are used here are likely an over-estimation. 100% intended consumption will
therefore translate to less than 100% actual consumption.
Only callable by Root or AdminOrigin.
bloat
Increase the block size by including the specified garbage bytes.
set_block_length
Set how much of the block length should be filled with trash data on each block.
1.0 means that all block should be filled. If set to 1.0, storage proof size will
be close to zero.
Only callable by Root or AdminOrigin.
Implementations
Sourceimpl<T: Config> Call<T>
impl<T: Config> Call<T>
Sourcepub fn new_call_variant_initialize_pallet(
new_count: u32,
witness_count: Option<u32>,
) -> Self
pub fn new_call_variant_initialize_pallet( new_count: u32, witness_count: Option<u32>, ) -> Self
Create a call with the variant initialize_pallet.
Sourcepub fn new_call_variant_set_compute(compute: FixedU64) -> Self
pub fn new_call_variant_set_compute(compute: FixedU64) -> Self
Create a call with the variant set_compute.
Sourcepub fn new_call_variant_set_storage(storage: FixedU64) -> Self
pub fn new_call_variant_set_storage(storage: FixedU64) -> Self
Create a call with the variant set_storage.
Sourcepub fn new_call_variant_bloat(garbage: Vec<[u8; 1024]>) -> Self
pub fn new_call_variant_bloat(garbage: Vec<[u8; 1024]>) -> Self
Create a call with the variant bloat.
Sourcepub fn new_call_variant_set_block_length(block_length: FixedU64) -> Self
pub fn new_call_variant_set_block_length(block_length: FixedU64) -> Self
Create a call with the variant set_block_length.